# 我的工作 
那个满脑子里只有钱、钱、钱的雷柏磷对我说：“现在流量正在狂暴轰入老师你，是时候该吃下这波涨粉推广你的作品了！”所以，我想简单介绍一下“旋牙暗雾”这个人在做什么，平时又在哪些网站上活跃。

  


从大学在校期间开始，我就一直在制作游戏和绘画漫画，从创建名为Underground Campaign的游戏工作室开始，至今我已经从事了大约20年的创作工作。

  


[图片]

  


今年我45岁了。

[图片]

  


我的个人网站可以通过以下链接查看。

  


https://lit.link/migiri

  


在Underground Campaign的官方网站上，可以查看游戏信息。

在FANBOX上，我会不时上传插画。

在X上，我会发布当天发生的事情和一些无关紧要的内容。

在カクヨム（Kakuyomu）上，我会以藍田レプン（Aida Repun）的名义撰写短篇恐怖和恋爱小说。

在BOOTH和デジケット（Digiket）上，可以购买我的作品。

  


如果有喜欢的网站，请务必收藏。

\-------------------------------------------------------------------------------

仕事大好きな雷君が

「フォロワーの増えた今こそ先生の仕事をPRする時です!」

と言ってきたので、旋牙闇霧って何をしているの?

普段はどのWebsiteにいるの?

ということを簡単にご紹介します。

  


私は大学在籍時からゲーム制作や漫画を描いていて、Underground Campaignというゲームスタジオを作ってからは20年くらい活動しています。

今年45歳になりました。

  


私が活動しているWebsiteは以下のリンクにまとめてあります。

  


https://lit.link/migiri

  


Underground Campaignの公式サイトではゲームの情報が閲覧できます。

FANBOXでは時々イラストをアップロードしています。

Xではその日あった出来事や、割とどうでもいいことを呟いています。

カクヨムでは藍田レプン名義で短編のホラーや恋愛小説を書いています。

BOOTHとデジケットでは私の作品が購入できます。

  


気に入ったサイトがあれば、ぜひブックマークしてくださいね。

(原文)

  


  


  

